/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
plugins {
    kotlin("jvm")
    alias(libs.plugins.composeCompiler)
    id("application")
    alias(libs.plugins.spotless)
}

dependencies {
    implementation(project(":temerity"))
    implementation(libs.jline)
    implementation(libs.mosaic)
}

application {
    mainClass = "edu.ucsc.its.temerity.console.ConsoleMainKt"
}

java {
    sourceCompatibility = JavaVersion.toVersion(libs.versions.java.get())
    targetCompatibility = JavaVersion.toVersion(libs.versions.java.get())
}

spotless {
    kotlin {
        target("**/*.kt")
        targetExclude("$buildDir/**/*.kt")
        ktlint().editorConfigOverride(
            mapOf(
                "indent_size" to "2",
                "continuation_indent_size" to "2"
            )
        )
        licenseHeaderFile(rootProject.file("spotless/appHeader.kt"))
        trimTrailingWhitespace()
        endWithNewline()
    }
    format("kts") {
        target("**/*.kts")
        targetExclude("$buildDir/**/*.kts")
        licenseHeaderFile(rootProject.file("spotless/appHeader.kt"), "(^(?![\\/ ]\\*).*$)")
        trimTrailingWhitespace()
        endWithNewline()
    }
}
